MatMiner Contributors — matminer 0.6.3 documentation

# matminer Contributors

Matminer is led by Anubhav Jain and the HackingMaterials research group at Lawrence Berkeley National Lab.

## LBNL - Hacking Materials

- Anubhav Jain

- Saurabh Bajaj (further contributions through Citrine Informatics)

- Alireza Faghaninia

- Nils Zimmermann

- Qi Wang

- Sayan Rowchowdhury

- Alex Dunn

- Jason Frost

- Julien Brenneck

- Alex Ganose

- Daniel Dopp

- Samy Cherfaoui

## University of Chicago

- Logan Ward

- Jiming Chen

- Ashwin Aggarwal

- Aik Rui

## LBNL - Persson Group

- Kiran Mathew

- Matt Horton

- Donny Winston

- Joseph Montoya

- Koki Muraoka

- Christian Legaspi

## Other

- Kyle Bystrom (Asta Research Group, UC Berkeley)

- Shyue Ping Ong (UC San Diego)

- Evgeny Blokhin (Tilde Lab)

- Max Dylla (Snyder Research Group, Northwestern University)

- David Waroquiers (UC Louvain, Belgium)

- Logan Williams (U Michigan Ann Arbor)

- Aidan Thompson (Sandia National Lab)

- Kamal Choudhary (NIST)

- Tian Xie (MIT)

- Daiki Nishikawa

- Nicholas Wagner (Northwestern University)

- Amalie Trewartha (LBNL)